@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.953.2.1 2020/08/24 15:10:21 kmos Exp $
+# $OpenBSD: Quirks.pm,v 1.1065 2020/09/25 21:40:55 bcallah Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -419,6 +419,66 @@ my $stem_extensions = {
 	'py-casttube' => 'py3-casttube',
 	'py-libcloud' => 'py3-libcloud',
 	'gegl03' => 'gegl04',
+	'py-mysql' => 'py-mysqlclient',
+# 6.8
+	'py-dulwich' => 'py3-dulwich',
+	'py-cups' => 'py3-cups',
+	'py-fastimport' => 'py3-fastimport',
+	'py-impacket' => 'py3-impacket',
+	'py-pynetbox' => 'py3-pynetbox',
+	'py-libvirt' => 'py3-libvirt',
+	'py-libxml' => 'py3-libxml',
+	'py-rsa' => 'py3-rsa',
+	'py-unicorn' => 'py3-unicorn',
+	'prison' => 'prison-kf5',
+	'kdegraphics-mobipocket' => 'kdegraphics-mobipocket-kf5',
+	'kdegraphics-thumbnailers' => 'kdegraphics-thumbnailers-kf5',
+	'svgpart' => 'svgpart-kf5',
+	'kdenetwork-filesharing' => 'kdenetwork-filesharing-kf5',
+	'spidermonkey60' => 'spidermonkey68',
+	'py-cloudpickle' => 'py3-cloudpickle',
+	'py-podcastparser' => 'py3-podcastparser',
+	'py-configargparse' => 'py3-configargparse',
+	'py-aiodns' => 'py3-aiodns',
+	'ebc' => 'bc-gh',
+	'py-cares' => 'py3-cares',
+	'py-astroid' => 'py3-astroid',
+	'pylint' => 'pylint3',
+	'pylint-gui' => 'pylint3-gui',
+	'py-M2Crypto' => 'py3-M2Crypto',
+	'sslscan-openssl' => 'sslscan',
+	'py-rarfile' => 'py3-rarfile',
+	'py-pygfm' => 'py3-pygfm',
+	'py-humanize' => 'py3-humanize',
+	'py-sabyenc' => 'py3-sabyenc',
+	'py-cftime' => 'py3-cftime',
+	'py-astral' => 'py3-astral',
+	'py-ropper' => 'py3-ropper',
+	'py-snuggs' => 'py3-snuggs',
+	'py-osqp' => 'py3-osqp',
+	'py-ecos' => 'py3-ecos',
+	'py-numexpr' => 'py3-numexpr',
+	'py-notmuch' => 'py3-notmuch',
+	'py-webpy' => 'py3-webpy',
+	'phonon-qt5' => 'phonon',
+	'phonon-qt5-gstreamer' => 'phonon-backend-gstreamer',
+	'phonon-qt5-vlc' => 'phonon-backend-vlc',
+	'phonon-gstreamer-icons' => 'phonon-backend-gstreamer',
+	'iosevka-fonts-default' => 'iosevka',
+	'iosevka-fonts-term' => 'iosevka',
+	'py-distutils-extra' => 'py3-distutils-extra',
+	'uqm-remix1' => 'uqm-remix',
+	'uqm-remix2' => 'uqm-remix',
+	'uqm-remix3' => 'uqm-remix',
+	'uqm-remix4' => 'uqm-remix',
+	'py-responses' => 'py3-responses',
+	'py-pudb' => 'py3-pudb',
+        'py-keyring' => 'py3-keyring',
+        'py-secretstorage' => 'py3-secretstorage',
+        'rgain' => 'rgain3',
+	'py-urwid' => 'py3-urwid',
+	'py-ply' => 'py3-ply',
+	'py-dtfabric' => 'py3-dtfabric',
 };
 
 my $obsolete_reason = {
@@ -1210,7 +1270,6 @@ my $obsolete_reason = {
 	'p5-Crypt-DH' => 13,
 	'p5-Crypt-Primes' => 13,
 	'p5-Crypt-RSA' => 13,
-	'p5-Crypt-OpenPGP' => 13,
 	'directoryassistant' => 0,
 	'x-pack' => 3,
 	'libepc' => 5,
@@ -1428,7 +1487,6 @@ my $obsolete_reason = {
 	'py3-typing' => 5,
 	'p5-Net-IRC' => 3,
 	'pangox-compat' => 0,
-	'qtserialport' => 5,
 	'tmake' => 5,
 	'qt3-sqlite3' => 5,
 	'eigen' => 5,
@@ -1557,6 +1615,241 @@ my $obsolete_reason = {
 	'jabberd' => 3,
 	'GeoIP' => 22,
 	'akpop3d' => 2,
+	'gtk+4-cloudprint' => 6,
+# 6.8
+	'planner' => 3,
+	'gnome-recipes' => 3,
+	'shared-color-targets' => 6,
+	'argyll' => 6,
+	'libcroco' => 3,
+	'libnipper' => 23,
+	'nipper' => 23,
+	'bg5pdf' => 13,
+	'pdflib' => 23,
+	'pop3gwd' => 3,
+	'tircd' => 3,
+	'gtksourceviewmm3' => 6,
+	'hpodder' => 3,
+	'hs-HDBC' => 5,
+	'hs-HDBC-sqlite3' => 5,
+	'hs-ConfigFile' => 5,
+	'hs-MissingH' => 5,
+	'hs-HaXml' => 5,
+	'py-gstreamer' => 5,
+	'py-libxslt' => 3,
+	'gconf-editor' => 3,
+	'amide' => 3,
+	'xmedcon' => 3,
+	'gq' => 3,
+	'gnome-doc-utils' => 3,
+	'rarian' => 3,
+	'qtcanvas3d' => 3,
+	'qtcanvas3d-examples' => 3,
+	'gtkparasite' => 3,
+	'gutenpy' => 3,
+	'klogic' => 3,
+	'soprano' => 3,
+	'automoc' => 3,
+	'qimageblitz' => 3,
+	'cagibi' => 3,
+	'libkvkontakte' => 3,
+	'libkfbapi' => 3,
+	'libkgapi' => 3,
+	'attica' => 3,
+	'kwebkitpart' => 3,
+	'grantlee' => 3,
+	'libkscreen' => 3,
+	'polkit-qt' => 3,
+	'phonon-gstreamer' => 3,
+	'phonon-gstreamer-icons' => 3,
+	'phonon-vlc' => 3,
+	'kde4-minimal' => 3,
+	'kde4' => 3,
+	'kde4-extras' => 3,
+	'kdeadmin' => 3,
+	'kdegames' => 3,
+	'kdenetwork' => 3,
+	'kdesdk' => 3,
+	'kdetoys' => 3,
+	'kdeadmin' => 3,
+	'kdegames' => 3,
+	'kdenetwork' => 3,
+	'kdesdk' => 3,
+	'kdetoys' => 3,
+	'kde-l10n-ar' => 3,
+	'kde-l10n-bg' => 3,
+	'kde-l10n-bs' => 3,
+	'kde-l10n-ca' => 3,
+	'kde-l10n-ca@valencia' => 3,
+	'kde-l10n-cs' => 3,
+	'kde-l10n-da' => 3,
+	'kde-l10n-de' => 3,
+	'kde-l10n-el' => 3,
+	'kde-l10n-en_GB' => 3,
+	'kde-l10n-es' => 3,
+	'kde-l10n-et' => 3,
+	'kde-l10n-eu' => 3,
+	'kde-l10n-fa' => 3,
+	'kde-l10n-fi' => 3,
+	'kde-l10n-fr' => 3,
+	'kde-l10n-ga' => 3,
+	'kde-l10n-gl' => 3,
+	'kde-l10n-he' => 3,
+	'kde-l10n-hi' => 3,
+	'kde-l10n-hr' => 3,
+	'kde-l10n-hu' => 3,
+	'kde-l10n-ia' => 3,
+	'kde-l10n-id' => 3,
+	'kde-l10n-is' => 3,
+	'kde-l10n-it' => 3,
+	'kde-l10n-ja' => 3,
+	'kde-l10n-kk' => 3,
+	'kde-l10n-km' => 3,
+	'kde-l10n-ko' => 3,
+	'kde-l10n-lt' => 3,
+	'kde-l10n-lv' => 3,
+	'kde-l10n-mr' => 3,
+	'kde-l10n-nb' => 3,
+	'kde-l10n-nds' => 3,
+	'kde-l10n-nl' => 3,
+	'kde-l10n-nn' => 3,
+	'kde-l10n-pa' => 3,
+	'kde-l10n-pl' => 3,
+	'kde-l10n-pt' => 3,
+	'kde-l10n-pt_BR' => 3,
+	'kde-l10n-ro' => 3,
+	'kde-l10n-ru' => 3,
+	'kde-l10n-sk' => 3,
+	'kde-l10n-sl' => 3,
+	'kde-l10n-sr' => 3,
+	'kde-l10n-sv' => 3,
+	'kde-l10n-tr' => 3,
+	'kde-l10n-ug' => 3,
+	'kde-l10n-uk' => 3,
+	'kde-l10n-wa' => 3,
+	'kde-l10n-zh_CN' => 3,
+	'kde-l10n-zh_TW' => 3,
+	'amor' => 3,
+	'audiocd-kio' => 3,
+	'baloo-widgets' => 3,
+	'ffmpegthumbs' => 3,
+	'jovie' => 3,
+	'kaccessible' => 3,
+	'kactivities' => 3,
+	'kde-base-artwork' => 3,
+	'kde-emoticons' => 3,
+	'kde-runtime' => 3,
+	'kde-shared-data' => 3,
+	'kde-wallpapers' => 3,
+	'kde-workspace' => 3,
+	'kde4-kopete-sounds' => 3,
+	'kde4-langlist' => 3,
+	'kde4-locale' => 3,
+	'kde4-locale-en_US' => 3,
+	'kdegraphics-strigi-analyzer' => 3,
+	'kdelibs' => 3,
+	'kdenetwork' => 3,
+	'kdenetwork-strigi-analyzers' => 3,
+	'kdepim' => 3,
+	'kdepim-runtime' => 3,
+	'kdepimlibs' => 3,
+	'kdeplasma-addons' => 3,
+	'kdesdk-strigi-analyzers' => 3,
+	'kdewebdev' => 3,
+	'kfilemetadata' => 3,
+	'kgamma' => 3,
+	'kgpg' => 3,
+	'kimono' => 3,
+	'kopete' => 3,
+	'korundum' => 3,
+	'kpat' => 3,
+	'kppp' => 3,
+	'kremotecontrol' => 3,
+	'kross-java' => 3,
+	'kscd' => 3,
+	'ktux' => 3,
+	'kuser' => 3,
+	'libkcddb' => 3,
+	'libkcompactdisc' => 3,
+	'libkdeedu' => 3,
+	'libkdegames' => 3,
+	'libkexiv2' => 3,
+	'mplayerthumbs' => 3,
+	'nepomuk-core' => 3,
+	'nepomuk-widgets' => 3,
+	'p5-kde' => 3,
+	'p5-qt' => 3,
+	'pairs' => 3,
+	'parley' => 3,
+	'py-kde' => 3,
+	'qyoto' => 3,
+	'ruby26-qt4' => 3,
+	'smokegen' => 3,
+	'smokekde' => 3,
+	'smokeqt' => 3,
+	'superkaramba' => 3,
+	'gbirthday' => 24,
+	'wireguard-go' => 4,
+	'wiresep' => 4,
+	'wireless' => 4,
+	'sisctrl' => 6,
+	'vteplugin' => 0,
+	'p5-Net-GPSD' => 5,
+	'mozplugger' => 0,
+	'ajaxterm' => 3,
+	'uim-kde' => 1,
+	'uim-qt' => 1,
+	'uim-qt4' => 1,
+	'dbusmenu-qt' => 5,
+	'qlandkartegt' => 25,
+	'qca' => 3,
+	'qca-gnupg' => 3,
+	'qca-ossl' => 3,
+	'keepassx' => 26,
+	'go-xlsx' => 7,
+	'go-check-v1' => 7,
+	'freemat' => 6,
+	'scim-qtimm' => 6,
+	'gambatte-qt' => 6,
+	'liblxqt-l10n' => 3,
+	'lxqt-about-l10n' => 3,
+	'lxqt-config-l10n' => 3,
+	'lxqt-notificationd-l10n' => 3,
+	'lxqt-openssh-askpass-l10n' => 3,
+	'lxqt-panel-l10n' => 3,
+	'lxqt-policykit-l10n' => 3,
+	'lxqt-powermanagement-l10n' => 3,
+	'lxqt-runner-l10n' => 3,
+	'lxqt-session-l10n' => 3,
+	'lxqt-sudo-l10n' => 3,
+	'lximage-l10n' => 3,
+	'compton-conf-l10n' => 3,
+	'obconf-l10n' => 3,
+	'libfm-qt-l10n' => 3,
+	'pavucontrol-qt-l10n' => 3,
+	'pcmanfm-qt-l10n' => 3,
+	'qtermwidget-l10n' => 3,
+	'qterminal-l10n' => 3,
+	'gmc4cc' => 6,
+	'py-sockjs-tornado' => 5,
+	'apache-activemq' => 5,
+	'libgda-ui' => 5,
+	'ocrfeeder' => 6,
+	'goocanvas2' => 5,
+	'py-termcolor' => 5,
+	'py3-termcolor' => 5,
+	'py-carddav' => 3,
+	'py-rdflib' => 5,
+	'py3-rdflib' => 5,
+	'fookebox' => 3,
+	'py-pylons' => 5,
+	'py-routes' => 5,
+	'py-weberror' => 5,
+	'py-webhelpers' => 5,
+	'hedgewars' => 0,
+	'lazarus' => 0,
+	'fpc' => 5,
+	'exaile' => 13,
 };
 
 # reasons for obsolete packages
@@ -1584,6 +1877,10 @@ my @msg = (
 	"merged into IETF Opus codec, obsolete, audio/mumble uses bundled version now", #20
 	"upstream recommends to use composer to build a drupal site", #21
 	"the original GeoIP database is end of life; use libmaxminddb/GeoIP2", #22
+	"no longer maintained upstream, became commercial over ten years ago", #23
+	"no longer maintained upstream, suggest qbirthday", #24
+	"no longer maintained upstream, suggest qmapshack", #25
+	"outdated Qt4 application, suggest keepassxc", #26
 );
 
 # ->is_base_system($handle, $state):
@@ -1683,6 +1980,7 @@ my $cve = {
 	'databases/postgresql,-main' => 'postgresql-client-<10.6',
 	'databases/postgresql,-server' => 'postgresql-server-<10.6',
 	'databases/sqlite3' => 'sqlite3-<3.25.3',
+	'devel/apache-ant' => 'apache-ant-<1.10.8',
 	'devel/git,-main' => 'git-<2.26.2',
 	'devel/git,-svn' => 'git-svn-<2.26.2',
 	'devel/git,-x11' => 'git-x11-<2.26.2',
@@ -1705,7 +2003,7 @@ my $cve = {
 	'lang/ruby/2.4,-main' => 'ruby->2.4,<2.4.5p2',
 	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
-	'mail/dovecot,-main' => 'dovecot-<2.3.6',
+	'mail/dovecot,-server' => 'dovecot-<2.3.10.1',
 	'mail/exim' => 'exim-<4.83',
 	'mail/mailman' => 'mailman-<2.1.30',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
@@ -1717,16 +2015,17 @@ my $cve = {
 	'net/haproxy' => 'haproxy-<2.0.14',
 	'net/icecast' => 'icecast-<2.4.4',
 	'net/irssi' => 'irssi-<1.2.1',
-	'net/isc-bind' => 'isc-bind-<9.11.5pl4v0',
+	'net/isc-bind' => 'isc-bind-<9.16.3',
 	'net/libssh2' => 'libssh2-<1.8.2',
 	'net/lldpd' => 'lldpd-<0.7.18p0',
 	'net/mosquitto' => 'mosquitto-<1.5.6',
 	'net/ntp' => 'ntp-<4.2.8pl7',
-	'net/openconnect' => 'openconnect-<8.05',
+	'net/openconnect' => 'openconnect-<8.10',
 	'net/openvpn' => 'openvpn-<2.4.9',
 	'net/powerdns,-main' => 'powerdns-<4.1.5',
 	'net/powerdns,-mysql' => 'powerdns-mysql-<4.1.5',
 	'net/powerdns,-pgsql' => 'powerdns-pgsql-<4.1.5',
+	'net/powerdns_recursor' => 'powerdns-recursor-<4.3.1',
 	'net/rsync' => 'rsync-<3.1.3p0',
 	'net/samba,-main' => 'samba-<4.8.18',
 	'net/tinc' => 'tinc-<1.0.35v0',
@@ -1750,7 +2049,7 @@ my $cve = {
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
 	'sysutils/salt' => 'salt-<2018.3.3p2',
 	'telephony/asterisk,-main' => 'asterisk-<13.23.1',
-	'telephony/coturn' => 'turnserver-<4.5.1.1',
+	'telephony/coturn' => 'turnserver-<4.5.1.2',
 	'www/apache-httpd,-main' => 'apache-httpd-<2.4.35',
 	'www/bozohttpd' => 'bozohttpd-<20130711p0',
 	'www/chromium' => 'chromium-<69.0.3497.100',
@@ -1773,9 +2072,14 @@ my $cve = {
 	'www/py-urllib3,python3' => 'py3-urllib3-<1.24.3',
 	'www/ruby-rack,ruby24' => 'ruby24-rack-<2.0.6',
 	'www/ruby-rack,ruby25' => 'ruby25-rack-<2.0.6',
+	'www/tomcat/v7' => 'tomcat-<7.0.104',
+	'www/tomcat/v8' => 'tomcat-<8.5.55',
+	'www/tomcat/v9' => 'tomcat-<9.0.35',
 	'www/webkitgtk4' => 'webkitgtk4-<2.20.5',
 	'x11/gnome/gdm' => 'gdm-<3.28.3',
 	'x11/rdesktop' => 'rdesktop-<1.8.4',
+	'net/zeromq' => 'zeromq-<4.3.3',
+	'net/libssh' => 'libssh-<0.9.5',
 };
 # please maintain sort order in above $cve list, future updates need to
 # replace existing entries
